[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# Python CI/CD with Buildkite

This repository serves as a code container for the tutorial I wrote on [Buildkite's blog](#todo).

> Blog link will be updated once the article is published.

## Features

- [x] Simple Utility functions
- [x] Publish documentation to Readthedocs.io
- [x] CI/CD with Buildkite

## Getting Started

Follow these instructions to get the project up and running.

```bash
# Clone the repo
git clone https://github.com/ravgeetdhillon/buildkite-python-ci-cd

# Change directory
$ cd buildkite-python-ci-cd

# Initialize virtual environment
$ python3 -m venv venv

# Install dependencies
$ pip install
```

> For detailed instructions, [read the blog](#todo).

## Tech Stack

- [Python](https://python.org)

## Authors

- [Ravgeet Dhillon](https://github.com/ravgeetdhillon)

## Extra

- You are welcome to make [issues and feature requests](https://github.com/ravgeetdhillon/buildkite-python-ci-cd/issues).
- In case you get stuck somewhere, feel free to contact me via [Mail](mailto:ravgeetdhillon@gmail.com).
